@@ -5,22 +5,21 @@ use 5.036;
 use AnyEvent;
 use Promise::XS;
 use Moo;
-use UserAgent::Any::Impl 'get_call_args', 'generate_methods', 'new_response';
+use UserAgent::Any::Impl::Helper ':all';
 
 use namespace::clean;
 
-with 'UserAgent::Any';
-extends 'UserAgent::Any::Impl';
+with 'UserAgent::Any::Impl';
 
 our $VERSION = 0.01;
 
 sub call {
-  my ($this, $method, $url, $params, $content) = &get_call_args;
+  my ($self, $method, $url, $params, $content) = &get_call_args;
   my $cv = AnyEvent->condvar;
   my $r;
-  $this->{ua}->$method(
+  $self->{ua}->$method(
     $url,
-    %{UserAgent::Any::Impl::params_to_hash(@{$params})},
+    %{params_to_hash(@{$params})},
     (defined ${$content} ? (Content => ${$content}) : ()),
     sub ($res) { $r = $res; $cv->send });
   $cv->recv;
@@ -28,11 +27,11 @@ sub call {
 }
 
 sub call_cb {
-  my ($this, $method, $url, $params, $content) = &get_call_args;
+  my ($self, $method, $url, $params, $content) = &get_call_args;
   return sub ($cb) {
-    $this->{ua}->$method(
+    $self->{ua}->$method(
       $url,
-      %{UserAgent::Any::Impl::params_to_hash(@{$params})},
+      %{params_to_hash(@{$params})},
       (defined ${$content} ? (Content => ${$content}) : ()),
       sub ($res) { $cb->(new_response($res)) });
     return;
@@ -40,11 +39,11 @@ sub call_cb {
 }
 
 sub call_p {
-  my ($this, $method, $url, $params, $content) = &get_call_args;
+  my ($self, $method, $url, $params, $content) = &get_call_args;
   my $p = Promise::XS::deferred();
-  $this->{ua}->$method(
+  $self->{ua}->$method(
     $url,
-    %{UserAgent::Any::Impl::params_to_hash(@{$params})},
+    %{params_to_hash(@{$params})},
     (defined ${$content} ? (Content => ${$content}) : ()),
     sub ($res) { $p->resolve(new_response($res)) });
   return $p->promise();
