@@ -5,20 +5,19 @@ use 5.036;
 use HTTP::Promise;
 use Moo;
 use Promise::Me;
-use UserAgent::Any::Impl 'get_call_args', 'generate_methods', 'new_response';
+use UserAgent::Any::Impl::Helper ':all';
 
 use namespace::clean;
 
-with 'UserAgent::Any';
-extends 'UserAgent::Any::Impl';
+with 'UserAgent::Any::Impl';
 
 our $VERSION = 0.01;
 
 sub call {
-  my ($this, $method, $url, $params, $content) = &get_call_args;
-  my $p = $this->{ua}->$method(
+  my ($self, $method, $url, $params, $content) = &get_call_args;
+  my $p = $self->{ua}->$method(
     $url,
-    %{UserAgent::Any::Impl::params_to_hash(@{$params})},
+    %{params_to_hash(@{$params})},
     (defined ${$content} ? (Content => ${$content}) : ())
   )->then(sub { return $_[0] });
   my @r = await($p);
@@ -26,11 +25,11 @@ sub call {
 }
 
 sub call_cb {
-  my ($this, $method, $url, $params, $content) = &get_call_args;
+  my ($self, $method, $url, $params, $content) = &get_call_args;
   return sub ($cb) {
-    $this->{ua}->$method(
+    $self->{ua}->$method(
       $url,
-      %{UserAgent::Any::Impl::params_to_hash(@{$params})},
+      %{params_to_hash(@{$params})},
       (defined ${$content} ? (Content => ${$content}) : ())
     )->then(sub { $cb->(new_response($_[0])) });
     return;
@@ -38,10 +37,10 @@ sub call_cb {
 }
 
 sub call_p {
-  my ($this, $method, $url, $params, $content) = &get_call_args;
-  return $this->{ua}->$method(
+  my ($self, $method, $url, $params, $content) = &get_call_args;
+  return $self->{ua}->$method(
     $url,
-    %{UserAgent::Any::Impl::params_to_hash(@{$params})},
+    %{params_to_hash(@{$params})},
     (defined ${$content} ? (Content => ${$content}) : ())
   )->then(sub { new_response($_[0]) });
 }
